"""Internal Accretion constants."""

ARTIFACTS_PREFIX = "accretion/artifacts/"
ARTIFACT_MANIFESTS_PREFIX = "accretion/manifests/"
SOURCE_PREFIX = "accretion/source/"
LAYER_MANIFESTS_PREFIX = "accretion/layers/"
